Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(714)

Unified Diff: chrome/browser/extensions/extension_service.h

Issue 10696210: Making ExtensionService less dependent on Browser. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Fixed clang build. Created 8 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/extensions/extension_service.h
diff --git a/chrome/browser/extensions/extension_service.h b/chrome/browser/extensions/extension_service.h
index 3673dc96daa12a8741f5bfe17dc7b53f3674b16e..2407685827cf2365f98a8707112a2681fc5835d6 100644
--- a/chrome/browser/extensions/extension_service.h
+++ b/chrome/browser/extensions/extension_service.h
@@ -51,8 +51,8 @@ class AppNotificationManager;
class BookmarkExtensionEventRouter;
class CrxInstaller;
class ExtensionBrowserEventRouter;
+class ExtensionErrorUI;
class ExtensionFontSettingsEventRouter;
-class ExtensionGlobalError;
class ExtensionManagedModeEventRouter;
class ExtensionManagementEventRouter;
class ExtensionPreferenceEventRouter;
@@ -561,13 +561,12 @@ class ExtensionService
// extensions.
void IdentifyAlertableExtensions();
// Given an ExtensionGlobalError alert, populates it with any extensions that
// need alerting. Returns true if the alert should be displayed at all.
//
// This method takes the extension_global_error argument rather than using
// the member variable to make it easier to test the method in isolation.
- bool PopulateExtensionGlobalError(
- ExtensionGlobalError* extension_global_error);
+ bool PopulateExtensionErrorUI(ExtensionErrorUI* extension_error_ui);
// Marks alertable extensions as acknowledged, after the user presses the
// accept button.
@@ -579,7 +578,7 @@ class ExtensionService
// Opens the Extensions page because the user wants to get more details
// about the alerts.
- void HandleExtensionAlertDetails(Browser* browser);
+ void HandleExtensionAlertDetails();
// Called when the extension alert is closed.
void HandleExtensionAlertClosed();
@@ -848,7 +847,7 @@ class ExtensionService
AppShortcutManager app_shortcut_manager_;
- scoped_ptr<ExtensionGlobalError> extension_global_error_;
+ scoped_ptr<ExtensionErrorUI> extension_error_ui_;
FRIEND_TEST_ALL_PREFIXES(ExtensionServiceTest,
InstallAppsWithUnlimtedStorage);
@@ -561,13 +561,12 @@ class ExtensionService
// extensions.
void IdentifyAlertableExtensions();
- // Given an ExtensionGlobalError alert, populates it with any extensions that
+ // Given an ExtensionErrorUI alert, populates it with any extensions that
// need alerting. Returns true if the alert should be displayed at all.
//
@@ -561,13 +561,12 @@ class ExtensionService
// need alerting. Returns true if the alert should be displayed at all.
//
- // This method takes the extension_global_error argument rather than using
+ // This method takes the extension_error_ui argument rather than using
// the member variable to make it easier to test the method in isolation.

Powered by Google App Engine
This is Rietveld 408576698